@@ -1,9 +1,9 @@
 //
 //  OSSP asgui - Accounting system graphical user interface
 //  Copyright (c) 2002-2003 The OSSP Project (http://www.ossp.org/)
-//  Copyright (c) 2002-2003 Cable & Wireless Deutschland (http://www.cw.com/de/)
 //  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
 //  Copyright (c) 2002-2003 Michael Schloh von Bennewitz <michael@schloh.com>
+//  Copyright (c) 2002-2003 Cable & Wireless Telecommunications Services GmbH
 //
 //  This file is part of OSSP asgui, an accounting system graphical user
 //  interface which can be found at http://www.ossp.org/pkg/tool/asgui/.
@@ -1888,11 +1888,10 @@ void Titraqform::aboutTitraq(void)
 {
     QString Namever = QString(TITRAQ_APPTITLE) + ' ' + asgui_version.v_short;
     QMessageBox *pCwmsg = new QMessageBox(Namever,
-        QObject::trUtf8("The as-gui is a time and task-based\n"
-               "accounting system that acts as both a\n"
-               "work-like punch card and time tracker.\n"
-               "Development of as-gui is sponsored by\n"
-               "Cable & Wireless Deutschland GmbH."),
+        QObject::trUtf8("The as-gui is a time and task-based accounting\n"
+               "system that acts as both a work-like punch card and\n"
+               "time tracker. Development of as-gui is sponsored by\n"
+               "Cable & Wireless Telecommunications Services GmbH."),
         QMessageBox::NoIcon, QMessageBox::Ok | QMessageBox::Default,
         QMessageBox::NoButton, QMessageBox::NoButton,
         NULL, "Titraqmessage", true, Qt::WStyle_NormalBorder);
